"""
Utils package for Family Safety Agent.

This package provides utilities for browser automation, page object models,
element finders, and action builders.
"""

from backend.utils.page_objects import (
    BasePage,
    ElementFinder,
    ClickableElementPage,
    FormPage,
    TogglePage,
    NavigationPage,
    DialogPage,
    ScrollPage,
    LinkPage,
)

from backend.utils.action_builders import (
    KeyboardActionBuilder,
    WaitActionBuilder,
    NavigationActionBuilder,
    EnsureToggleActionBuilder,
    ClickActionBuilder,
    TypeActionBuilder,
    HoverActionBuilder,
    ScrollActionBuilder,
    ActionBuilderFactory,
)

__all__ = [
    # Page Objects
    "BasePage",
    "ElementFinder",
    "ClickableElementPage",
    "FormPage",
    "TogglePage",
    "NavigationPage",
    "DialogPage",
    "ScrollPage",
    "LinkPage",
    # Action Builders
    "KeyboardActionBuilder",
    "WaitActionBuilder",
    "NavigationActionBuilder",
    "EnsureToggleActionBuilder",
    "ClickActionBuilder",
    "TypeActionBuilder",
    "HoverActionBuilder",
    "ScrollActionBuilder",
    "ActionBuilderFactory",
]
