"""
Web AI agent - re-exports from backend utils.
"""

import sys
from pathlib import Path

_backend_dir = Path(__file__).resolve().parent.parent.parent
if str(_backend_dir) not in sys.path:
    sys.path.insert(0, str(_backend_dir))

from agents.ai_agents_web import AIAdhocWebAgent

__all__ = ["AIAdhocWebAgent"]
